# -*- coding: utf-8 -*-

class ObjectType1Enum(object):

    """Implementation of the 'ObjectType1' enum.

    Specifies the object type to be searched for.

    Attributes:
        EMAILS: TODO: type description here.
        FILES: TODO: type description here.
        CASSANDRAOBJECTS: TODO: type description here.
        COUCHBASEOBJECTS: TODO: type description here.
        HBASEOBJECTS: TODO: type description here.
        HIVEOBJECTS: TODO: type description here.
        MONGOOBJECTS: TODO: type description here.
        HDFSOBJECTS: TODO: type description here.
        PUBLICFOLDERS: TODO: type description here.
        EXCHANGEOBJECTS: TODO: type description here.

    """

    EMAILS = 'Emails'

    FILES = 'Files'

    CASSANDRAOBJECTS = 'CassandraObjects'

    COUCHBASEOBJECTS = 'CouchbaseObjects'

    HBASEOBJECTS = 'HbaseObjects'

    HIVEOBJECTS = 'HiveObjects'

    MONGOOBJECTS = 'MongoObjects'

    HDFSOBJECTS = 'HDFSObjects'

    PUBLICFOLDERS = 'PublicFolders'

    EXCHANGEOBJECTS = 'ExchangeObjects'
